@@ -4,6 +4,7 @@ import json
 import time
 from glob import glob
 import pandas as pd
+import numpy as np
 
 
 def add_start_date(participants_folder_path_list, info_dict):
@@ -28,8 +29,35 @@ def add_start_date(participants_folder_path_list, info_dict):
                 break # only executed if the inner loop DID break
     return info_dict
 
+def read_json(json_path):
+    with open(json_path) as f:
+        data = json.load(f)
+    return data
 
-def create_json(intermediate_participant_path, output_dir_path):
+def add_home_locations(lsf_json_folder_path, info_dict):
+    for participant_id in info_dict:
+        lsf_json_path = os.path.join(lsf_json_folder_path, participant_id, "lsf.json")
+        if not os.path.exists(lsf_json_path):
+            continue
+        else:
+            lsf_json = read_json(lsf_json_path)
+            labels = lsf_json["label"]
+            bboxes = lsf_json["bbox"]
+            home_coord_list = []
+            for clusterID in labels:
+                if "Home" in labels[clusterID]:
+                    if clusterID in bboxes:
+                        bbox = bboxes[clusterID]
+                        home_lat = np.mean([bbox[0], bbox[1]])
+                        home_lon = np.mean([bbox[2], bbox[3]])
+                        home_coord = [home_lat, home_lon]
+                        home_coord_list.append(home_coord)
+            info_dict[participant_id]['home_loc'] = home_coord_list
+
+    return info_dict
+
+
+def create_json(intermediate_participant_path, output_dir_path, lsf_json_folder_path):
     print("Creating new participant info json.")
     info_dict = dict()
     misc_folder_name = "misc"
@@ -39,10 +67,14 @@ def create_json(intermediate_participant_path, output_dir_path):
     if not os.path.exists(folder_path):
         os.makedirs(folder_path)
 
+    # start_date
     intermediate_folder_path = os.path.abspath(os.path.join(intermediate_participant_path, os.pardir))
-
     participants_folder_path_list = list(glob(os.path.join(intermediate_folder_path, "*@timestudy_com")))
     info_dict = add_start_date(participants_folder_path_list, info_dict)
+
+    # home location
+    info_dict = add_home_locations(lsf_json_folder_path, info_dict)
+
     # dump json file
     with open(information_dict_path, 'w') as f:
         json.dump(info_dict, f)
@@ -51,7 +83,7 @@ def create_json(intermediate_participant_path, output_dir_path):
     return info_dict
 
 
-def execute(intermediate_participant_path, output_dir_path):
+def execute(intermediate_participant_path, output_dir_path, lsf_json_folder_path):
 
     misc_folder_name = "misc"
     information_dict_name = "info.json"
@@ -61,7 +93,7 @@ def execute(intermediate_participant_path, output_dir_path):
     if not os.path.exists(information_dict_path): # when the json needs to be updated
         if not os.path.exists(folder_path):
             os.makedirs(folder_path)
-        info_dict = create_json(intermediate_participant_path, output_dir_path)
+        info_dict = create_json(intermediate_participant_path, output_dir_path, lsf_json_folder_path)
     else:
         # Load existing json file
         # if os.path.exists(information_dict_path):
